@@ -3,54 +3,50 @@ from argparse import ArgumentParser
 
 import pytorch_lightning as pl
 import torch
-
-import torch. nn as nn
+from torch import nn as nn
 from torch.nn import functional as F
 
-from pl_bolts.datamodules import (BinaryMNISTDataModule, CIFAR10DataModule,
-                                  ImagenetDataModule, MNISTDataModule,
-                                  STL10DataModule)
-from pl_bolts.models.autoencoders.components import resnet18_encoder, resnet18_decoder
-from pl_bolts.models.autoencoders.components import resnet50_encoder, resnet50_decoder
+from pl_bolts import _HTTPS_AWS_HUB
+from pl_bolts.models.autoencoders.components import (
+    resnet18_decoder,
+    resnet18_encoder,
+    resnet50_decoder,
+    resnet50_encoder,
+)
 
 
 class AE(pl.LightningModule):
+    """
+    Standard AE
+
+    Model is available pretrained on different datasets:
+
+    Example::
+
+        # not pretrained
+        ae = AE()
+
+        # pretrained on cifar10
+        ae = AE.from_pretrained('cifar10-resnet18')
+    """
 
     pretrained_urls = {
-        'cifar10-resnet18':
-            'https://pl-bolts-weights.s3.us-east-2.amazonaws.com/ae/ae-cifar10/checkpoints/epoch%3D96.ckpt'
+        'cifar10-resnet18': os.path.join(_HTTPS_AWS_HUB, 'ae/ae-cifar10/checkpoints/epoch%3D96.ckpt'),
     }
 
     def __init__(
         self,
-        input_height,
-        enc_type='resnet18',
-        first_conv=False,
-        maxpool1=False,
-        enc_out_dim=512,
-        kl_coeff=0.1,
-        latent_dim=256,
-        lr=1e-4,
-        **kwargs
+        input_height: int,
+        enc_type: str = 'resnet18',
+        first_conv: bool = False,
+        maxpool1: bool = False,
+        enc_out_dim: int = 512,
+        latent_dim: int = 256,
+        lr: float = 1e-4,
+        **kwargs,
     ):
         """
-        Standard AE
-
-        Model is available pretrained on different datasets:
-
-        Example::
-
-            # not pretrained
-            ae = AE()
-
-            # pretrained on imagenet
-            ae = AE.from_pretrained('resnet50-imagenet')
-
-            # pretrained on cifar10
-            ae = AE.from_pretrained('resnet18-cifar10')
-
         Args:
-
             input_height: height of the images
             enc_type: option between resnet18 or resnet50
             first_conv: use standard kernel_size 7, stride 2 at start or
@@ -72,8 +68,14 @@ class AE(pl.LightningModule):
         self.input_height = input_height
 
         valid_encoders = {
-            'resnet18': {'enc': resnet18_encoder, 'dec': resnet18_decoder},
-            'resnet50': {'enc': resnet50_encoder, 'dec': resnet50_decoder},
+            'resnet18': {
+                'enc': resnet18_encoder,
+                'dec': resnet18_decoder,
+            },
+            'resnet50': {
+                'enc': resnet50_encoder,
+                'dec': resnet50_decoder,
+            },
         }
 
         if enc_type not in valid_encoders:
@@ -95,8 +97,11 @@ class AE(pl.LightningModule):
 
         return self.load_from_checkpoint(AE.pretrained_urls[checkpoint_name], strict=False)
 
-    def forward(self, z):
-        return self.decoder(z)
+    def forward(self, x):
+        feats = self.encoder(x)
+        z = self.fc(feats)
+        x_hat = self.decoder(z)
+        return x_hat
 
     def step(self, batch, batch_idx):
         x, y = batch
@@ -111,17 +116,13 @@ class AE(pl.LightningModule):
 
     def training_step(self, batch, batch_idx):
         loss, logs = self.step(batch, batch_idx)
-        result = pl.TrainResult(minimize=loss)
-        result.log_dict(
-            {f"train_{k}": v for k, v in logs.items()}, on_step=True, on_epoch=False
-        )
-        return result
+        self.log_dict({f"train_{k}": v for k, v in logs.items()}, on_step=True, on_epoch=False)
+        return loss
 
     def validation_step(self, batch, batch_idx):
         loss, logs = self.step(batch, batch_idx)
-        result = pl.EvalResult(checkpoint_on=loss)
-        result.log_dict({f"val_{k}": v for k, v in logs.items()})
-        return result
+        self.log_dict({f"val_{k}": v for k, v in logs.items()})
+        return loss
 
     def configure_optimizers(self):
         return torch.optim.Adam(self.parameters(), lr=self.lr)
@@ -136,7 +137,9 @@ class AE(pl.LightningModule):
         parser.add_argument("--lr", type=float, default=1e-4)
 
         parser.add_argument(
-            "--enc_out_dim", type=int, default=512,
+            "--enc_out_dim",
+            type=int,
+            default=512,
             help="512 for resnet18, 2048 for bigger resnets, adjust for wider resnets"
         )
         parser.add_argument("--latent_dim", type=int, default=256)
@@ -145,21 +148,14 @@ class AE(pl.LightningModule):
         parser.add_argument("--num_workers", type=int, default=8)
         parser.add_argument("--data_dir", type=str, default=".")
 
-        parser.add_argument("--gpus", type=int, default=1)
-        parser.add_argument("--max_epochs", type=int, default=200)
-        parser.add_argument("--max_steps", type=int, default=-1)
-        parser.add_argument("--fast_dev_run", action='store_true')
-
         return parser
 
 
 def cli_main(args=None):
-    from pl_bolts.callbacks import LatentDimInterpolator, TensorboardGenerativeModelImageSampler
-
-    # cli_main()
+    from pl_bolts.datamodules import CIFAR10DataModule, ImagenetDataModule, STL10DataModule
 
     parser = ArgumentParser()
-    parser.add_argument("--dataset", default="cifar10", type=str, help="cifar10, stl10, imagenet")
+    parser.add_argument("--dataset", default="cifar10", type=str, choices=["cifar10", "stl10", "imagenet"])
     script_args, _ = parser.parse_known_args(args)
 
     if script_args.dataset == "cifar10":
@@ -172,6 +168,7 @@ def cli_main(args=None):
         raise ValueError(f"undefined dataset {script_args.dataset}")
 
     parser = AE.add_model_specific_args(parser)
+    parser = pl.Trainer.add_argparse_args(parser)
     args = parser.parse_args(args)
 
     dm = dm_cls.from_argparse_args(args)
@@ -181,10 +178,9 @@ def cli_main(args=None):
         args.max_steps = None
 
     model = AE(**vars(args))
-    callbacks = [TensorboardGenerativeModelImageSampler()]
 
     trainer = pl.Trainer.from_argparse_args(args)
-    trainer.fit(model, dm)
+    trainer.fit(model, datamodule=dm)
     return dm, model, trainer
 
 
