@@ -1,14 +1,33 @@
-import os
 from argparse import ArgumentParser
 
 import pytorch_lightning as pl
 import torch
 from torch.nn import functional as F
 
-from pl_bolts.models.gans.basic.components import Generator, Discriminator
+from pl_bolts.models.gans.basic.components import Discriminator, Generator
 
 
 class GAN(pl.LightningModule):
+    """
+    Vanilla GAN implementation.
+
+    Example::
+
+        from pl_bolts.models.gan import GAN
+
+        m = GAN()
+        Trainer(gpus=2).fit(m)
+
+    Example CLI::
+
+        # mnist
+        python  basic_gan_module.py --gpus 1
+
+        # imagenet
+        python  basic_gan_module.py --gpus 1 --dataset 'imagenet2012'
+        --data_dir /path/to/imagenet/folder/ --meta_dir ~/path/to/meta/bin/folder
+        --batch_size 256 --learning_rate 0.0001
+    """
 
     def __init__(
         self,
@@ -20,34 +39,12 @@ class GAN(pl.LightningModule):
         **kwargs
     ):
         """
-        Vanilla GAN implementation.
-
-        Example::
-
-            from pl_bolts.models.gan import GAN
-
-            m = GAN()
-            Trainer(gpus=2).fit(m)
-
-        Example CLI::
-
-            # mnist
-            python  basic_gan_module.py --gpus 1
-
-            # imagenet
-            python  basic_gan_module.py --gpus 1 --dataset 'imagenet2012'
-            --data_dir /path/to/imagenet/folder/ --meta_dir ~/path/to/meta/bin/folder
-            --batch_size 256 --learning_rate 0.0001
-
         Args:
-
-            datamodule: the datamodule (train, val, test splits)
+            input_channels: number of channels of an image
+            input_height: image height
+            input_width: image width
             latent_dim: emb dim for encoder
-            batch_size: the batch size
             learning_rate: the learning rate
-            data_dir: where to store data
-            num_workers: data workers
-
         """
         super().__init__()
 
@@ -137,18 +134,16 @@ class GAN(pl.LightningModule):
 
         # log to prog bar on each step AND for the full epoch
         # use the generator loss for checkpointing
-        result = pl.TrainResult(minimize=g_loss, checkpoint_on=g_loss)
-        result.log('g_loss', g_loss, on_epoch=True, prog_bar=True)
-        return result
+        self.log('g_loss', g_loss, on_epoch=True, prog_bar=True)
+        return g_loss
 
     def discriminator_step(self, x):
         # Measure discriminator's ability to classify real from generated samples
         d_loss = self.discriminator_loss(x)
 
         # log to prog bar on each step AND for the full epoch
-        result = pl.TrainResult(minimize=d_loss)
-        result.log('d_loss', d_loss, on_epoch=True, prog_bar=True)
-        return result
+        self.log('d_loss', d_loss, on_epoch=True, prog_bar=True)
+        return d_loss
 
     def configure_optimizers(self):
         lr = self.hparams.learning_rate
@@ -161,12 +156,13 @@ class GAN(pl.LightningModule):
     def add_model_specific_args(parent_parser):
         parser = ArgumentParser(parents=[parent_parser], add_help=False)
         parser.add_argument('--learning_rate', type=float, default=0.0002, help="adam: learning rate")
-        parser.add_argument('--adam_b1', type=float, default=0.5,
-                            help="adam: decay of first order momentum of gradient")
-        parser.add_argument('--adam_b2', type=float, default=0.999,
-                            help="adam: decay of first order momentum of gradient")
-        parser.add_argument('--latent_dim', type=int, default=100,
-                            help="generator embedding dim")
+        parser.add_argument(
+            '--adam_b1', type=float, default=0.5, help="adam: decay of first order momentum of gradient"
+        )
+        parser.add_argument(
+            '--adam_b2', type=float, default=0.999, help="adam: decay of first order momentum of gradient"
+        )
+        parser.add_argument('--latent_dim', type=int, default=100, help="generator embedding dim")
         return parser
 
 
@@ -198,7 +194,7 @@ def cli_main(args=None):
     model = GAN(*dm.size(), **vars(args))
     callbacks = [TensorboardGenerativeModelImageSampler(), LatentDimInterpolator(interpolate_epoch_interval=5)]
     trainer = pl.Trainer.from_argparse_args(args, callbacks=callbacks, progress_bar_refresh_rate=20)
-    trainer.fit(model, dm)
+    trainer.fit(model, datamodule=dm)
     return dm, model, trainer
 
 
