@@ -1,12 +1,12 @@
 import numpy as np
 import torch
+from torch import Tensor
 
 
-def tile(a, dim, n_tile):
+def tile(a: Tensor, dim: int, n_tile: int) -> Tensor:
     init_dim = a.size(dim)
     repeat_idx = [1] * a.dim()
     repeat_idx[dim] = n_tile
     a = a.repeat(*repeat_idx)
     order_index = torch.LongTensor(np.concatenate([init_dim * np.arange(n_tile) + i for i in range(init_dim)]))
-    order_index = order_index.type_as(a).long()
     return torch.index_select(a, dim, order_index)
